@@ -45,21 +45,10 @@ class _WebDriver(object):
     """As agent of the webdriver.WebDriver"""
     def __init__(self, driver: RemoteWebDriver):
         self._driver = driver
-        self._is_idle = False
 
     def __getattr__(self, item):
         return getattr(self._driver, item)
 
-    def set_idle(self):
-        self._is_idle = True
-
-    def set_busy(self):
-        self._is_idle = False
-
-    @property
-    def is_idle(self):
-        return self._is_idle
-
     def current_response(self, request):
         return HtmlResponse(self.current_url,
                             body=str.encode(self.page_source),
